@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: pandoc-crossref
 version: 0.2.0.1
-id: pandoc-crossref-0.2.0.1-3e3851b39cc7290c474d35f835552834
-key: pando_87yR5rmmxUo2TQCNfckW50
+id: pandoc-crossref-0.2.0.1-1e6adb35709d10aae9313e894723b87a
+key: pando_DzO7sw9sMBC2UAQlN5upkf
 license: GPL-2
 maintainer: root@livid.pp.ru
 synopsis: Pandoc filter for cross-references
@@ -32,7 +32,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-crossref-0.2.0.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-crossref-0.2.0.1
 data-dir: /usr/share/pandoc-crossref
-hs-libraries: HSpandoc-crossref-0.2.0.1-87yR5rmmxUo2TQCNfckW50
+hs-libraries: HSpandoc-crossref-0.2.0.1-DzO7sw9sMBC2UAQlN5upkf
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
@@ -42,12 +42,12 @@ depends:
     data-accessor-transformers-0.2.1.7-082e9d05eabfdcb5b212785d058bd96b
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
-    pandoc-1.17.0.3-257df634e15a54e32a712d876ce77ba5
+    pandoc-1.17.0.3-eb510c613bb58261320cda2a21b65c87
     pandoc-types-1.16.1-5c682c2b5cffa962280d4abd090bac44
     roman-numerals-0.5.1.5-895a0ef14eb8678de90c7da056b82bde
     syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
-    yaml-0.8.16-50dd72d7df25e45cd672d7359cb18648
+    yaml-0.8.17-256008eb42bc8c59588e1e26ecb14272
 haddock-interfaces: /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
 haddock-html: /usr/share/doc/pandoc-crossref/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
